<th>
    <center>
        All in Filter
        <input type="checkbox" id="select-all-pages-checkbox" /> <br>
        All on Page
        <input type="checkbox" id="select-all-objects-checkbox" onclick="toggle_select_all_objects();" />
    </center>
</th>